init_status: Initial Status of Individuals in the Network

Description Usage Arguments Value

Description

init_status returns a binary array of the initial infectious status of individuals in the network (0 = susceptible, 1 = infectious).

Usage

1
init_status(N, startnodes)

Arguments

N

Number of vertices / nodes in the network.

startnodes

Initially infectious individuals.

Value

Integer array of size N representing binary infectious status.


tjtnew/simnetr documentation built on May 8, 2019, 1:53 p.m.